@@ -1,9 +1,9 @@
 from .models import ChatRequest, ImageInput, ChatHistoryRequest, FileInput
 from .client.ChatClient import ChatClient
-from .uploader import FileUploader
+from .uploader import FileUploader, create_file_like
 from . import api
 
-__all__ = ["ChatRequest", "ImageInput", "ChatClient", "FileUploader", "ChatHistoryRequest", "FileInput", "api"]
+__all__ = ["ChatRequest", "ImageInput", "ChatClient", "FileUploader", "ChatHistoryRequest", "FileInput", "api", "create_file_like"]
 
 
 def main() -> None:
