@@ -1,4 +1,4 @@
-from src.autoagentsai.client import ChatClient
+from autoagentsai.client import ChatClient
 from io import BytesIO
 
 client = ChatClient(
